# [cratt](https://github.com/ccrsxx/cratt) &middot; [![Upload Python Package](https://github.com/ccrsxx/cratt/actions/workflows/python-publish.yml/badge.svg)](https://github.com/ccrsxx/cratt/actions/workflows/python-publish.yml) [![PyPI Latest Release](https://img.shields.io/pypi/v/cratt.svg)](https://pypi.org/project/cratt) [![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A CLI for creating React App with TypeScript and TailwindCSS. It comes already configured with ESLint, Prettier, and Husky. Also, It can automatically push the project to Github, add relevant tags and description, and deploy it to Github Pages.

## Prerequisites

You need to have [`Python`](https://www.python.org/downloads/) and [`GitHub CLI`](https://cli.github.com/) installed on your machine.

## Installation

1. First of all, install the package using `pip`:

   ```bash
   pip install cratt
   ```

2. Then, run the command to create a new project:

   ```bash
   cra new-app
   ```
